/* eslint-disable react/no-array-index-key */

// @flow

import React from 'react'
import cn from 'classnames'

type LinkData = {
  label: string,
  href: string,
}

type PricingTableItem = {
  name: string,
  popular?: boolean,
  theme?: {
    root?: string,
    name?: string,
    price?: string,
    body?: string,
    item?: string,
    callToAction?: string,
  },
  price: number | string,
  items: Array<string>,
  callToAction: LinkData,
}

type PricingTableData = {
  fields?: Array<string>,
  data: { [key: string]: PricingTableItem }
}

const PricingCard = ({
  className,
  item: { name, price, items, callToAction, theme = {} },
  renderLink,
}: {
  className?: string,
  item: PricingTableItem,
  renderLink?: (callToAction: LinkData) => any,
}) => (
  <div className={cn(className, theme.root)}>
    <div className={theme.name}>{name}</div>
    <div className={theme.price}>{price}</div>
    <div className={theme.body}>
      {items.map((value, index) => (
        <div className={theme.item} key={index}>{value}</div>
      ))}
    </div>
    <div className={theme.callToAction}>
      {!renderLink && (
        <span>{callToAction.label}</span>
      )}
      {!!renderLink && renderLink(callToAction)}
    </div>
  </div>
)

PricingCard.defaultProps = {
  className: null,
  renderLink: null,
}

const PricingTable = ({
  className,
  data: { fields = [], data },
  renderLink,
}: {
  className?: string,
  data: PricingTableData,
  renderLink?: (callToAction: LinkData) => any,
}) => {
  const keys = Object.keys(data)
  return (
    <div className={className}>
      {fields.length > 0 && (
        <div>
          {fields.map(x => (
            <div key={x}>{x}</div>
          ))}
        </div>
      )}
      <div className="flex">
        {keys.map(key => (
          <PricingCard
            className="flex-auto"
            item={data[key]}
            renderLink={renderLink}
          />
        ))}
      </div>
    </div>
  )
}

PricingTable.defaultProps = {
  className: null,
  renderLink: null,
}

export default PricingTable
