// @flow

import React from 'react'
import Section from 'components/Section'

const Sections = ({
  sections,
  className,
  themes,
  Link,
}: {
  sections: Array<TSection>,
  className?: string,
  themes: Array<{
    id: string,
    theme: { [key: string]: string },
    childrenTheme: { [key: string]: string },
  }>,
  Link: any,
}) => {
  const keys = sections.map(x => x.id)
  const sectionMap = sections.reduce((acc, value) => ({
    ...acc,
    [value.id]: value,
  }), {})
  const themeMap = themes.reduce((acc, value) => ({
    ...acc,
    [value.id]: value,
  }), {})

  return (
    <div className={className}>
      {keys.map((key) => {
        const themeId = sectionMap[key].themeId || key
        const { theme = {}, childrenTheme = {} } = themeMap[themeId] || {}
        return (
          <Section
            key={key}
            section={sectionMap[key]}
            theme={theme}
            childrenTheme={childrenTheme}
            Link={Link}
          />
        )
      })}
    </div>
  )
}

Sections.defaultProps = {
  className: null,
}

export default Sections
